/**********************************************************************************************/
/*                                                                                            */
/*                                   3-Wire.                                       */
/*                                                                                            */
/**********************************************************************************************/
#include  "3Wire.h"


/*--------------------------------------------------------------------------------------------*/
/*     3-Wire.                                              */
/* :     .                                                          */
/* :    .                                                         */
/*--------------------------------------------------------------------------------------------*/
void Three_Wire_Init(void)
{
  Set_Line_in_Port_to_Output(THREE_WIRE_CLK_PIN); Clr_Line_in_Port(THREE_WIRE_CLK_PIN);
  Set_Line_in_Port_to_Input(THREE_WIRE_DQ_PIN); Set_Line_in_Port(THREE_WIRE_DQ_PIN);
  return;
}

/*--------------------------------------------------------------------------------------------*/
/*   1    3-Wire.                                                 */
/* :    .                                                            */
/* :    .                                                         */
/*--------------------------------------------------------------------------------------------*/
void Send_Byte_on_3Wire(IN BYTE byte)
{
  Set_Line_in_Port_to_Output(THREE_WIRE_DQ_PIN);
  for(register BYTE i = 0; i < 8; i++, byte >>= 1)
     {
       ((byte & 0x01) == 0) ? (Clr_Line_in_Port(THREE_WIRE_DQ_PIN)) : (Set_Line_in_Port(THREE_WIRE_DQ_PIN));
       Clr_Line_in_Port(THREE_WIRE_CLK_PIN);
       __delay_mks(1);
       Set_Line_in_Port(THREE_WIRE_CLK_PIN);
       __delay_mks(1);
     }
  return;
}

/*--------------------------------------------------------------------------------------------*/
/*   n    3-Wire.                                                */
/* :      ,   .                 */
/* :    .                                                         */
/*--------------------------------------------------------------------------------------------*/
void Send_Bytes_on_3Wire(IN BYTE __flash *pData, IN BYTE n)
{
  for(register BYTE i = 0; i < n; i++, pData++) Send_Byte_on_3Wire(*pData);
  return;
}

/*--------------------------------------------------------------------------------------------*/
/*   n    3-Wire.                                                */
/* :      ,   .                 */
/* :    .                                                         */
/*--------------------------------------------------------------------------------------------*/
void Send_Bytes_on_3Wire(IN BYTE *pData, IN BYTE n)
{
  for(register BYTE i = 0; i < n; i++, pData++) Send_Byte_on_3Wire(*pData);
  return;
}

/*--------------------------------------------------------------------------------------------*/
/*   n     3-Wire.                                           */
/* :    ,   .                                      */
/* :    .                                                         */
/*--------------------------------------------------------------------------------------------*/
void Send_Bytes_on_3Wire(IN BYTE byte, IN BYTE n)
{
  for(register BYTE i = 0; i < n; i++) Send_Byte_on_3Wire(byte);
  return;
}

/*--------------------------------------------------------------------------------------------*/
/*   1    3-Wire.                                                 */
/* :     .                                                          */
/* :   .                                                               */
/*--------------------------------------------------------------------------------------------*/
OUT BYTE Get_Byte_from_3Wire(void)
{
  register BYTE byte = 0;
  Set_Line_in_Port_to_Input(THREE_WIRE_DQ_PIN); Set_Line_in_Port(THREE_WIRE_DQ_PIN);
  for(register BYTE i = 0; i < 8; i++)
     {
       byte >>= 1;
       Set_Line_in_Port(THREE_WIRE_CLK_PIN);
       __delay_mks(1);
       Clr_Line_in_Port(THREE_WIRE_CLK_PIN);
       __delay_mks(1);
       if(is_Input_Line_in_Port_Set(THREE_WIRE_DQ_PIN)) byte |= 0x80;
     }
  return byte;
}

/*--------------------------------------------------------------------------------------------*/
/*   n     3-Wire.                                         */
/* :       ,   .                 */
/* :    .                                                         */
/*--------------------------------------------------------------------------------------------*/
void Get_Bytes_from_3Wire(OUT BYTE *pData, IN BYTE n)
{
  for(register BYTE i = 0; i < n; i++, pData++) *pData = Get_Byte_from_3Wire();
  return;
}


/**********************************************************************************************/
